==> haskell-csv-0.1.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 csv
version:              0.1.2
visibility:           public
id:                   csv-0.1.2-KfEh9jcA2ivFhj7vIMb1xn
key:                  csv-0.1.2-KfEh9jcA2ivFhj7vIMb1xn
license:              MIT
copyright:            Jaap Weel, 2007
maintainer:           Jaap Weel <weel@ugcs.caltech.edu>
author:               Jaap Weel <weel@ugcs.caltech.edu>
synopsis:             CSV loader and dumper
description:
    CSV loader and dumper

    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.

category:             Text
abi:                  65063547fce4742307cc357f4e61ff4c
exposed:              True
exposed-modules:      Text.CSV
import-dirs:          /usr/lib/ghc-8.8.3/site-local/csv-0.1.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/csv-0.1.2
hs-libraries:         HScsv-0.1.2-KfEh9jcA2ivFhj7vIMb1xn
depends:              base-4.13.0.0 filepath-1.4.2.1 parsec-3.1.14.0
haddock-interfaces:   /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html:         /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-csv-0.1.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 csv
version:              0.1.2
visibility:           public
id:                   csv-0.1.2-AHgHoDB69MGJeZuXGUiAav
key:                  csv-0.1.2-AHgHoDB69MGJeZuXGUiAav
license:              MIT
copyright:            Jaap Weel, 2007
maintainer:           Jaap Weel <weel@ugcs.caltech.edu>
author:               Jaap Weel <weel@ugcs.caltech.edu>
synopsis:             CSV loader and dumper
description:
    CSV loader and dumper

    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.

category:             Text
abi:                  9863f61ed02096726c473f5f849b0ef8
exposed:              True
exposed-modules:      Text.CSV
import-dirs:          /usr/lib/ghc-8.10.1/site-local/csv-0.1.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/csv-0.1.2
hs-libraries:         HScsv-0.1.2-AHgHoDB69MGJeZuXGUiAav
depends:              base-4.14.0.0 filepath-1.4.2.1 parsec-3.1.14.0
haddock-interfaces:   /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html:         /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
